==> github2-0.4.0.tar.gz: github2-0.4.0/tests/test_commits.py <==
import _setup

import sys

from nose.tools import (assert_equals, assert_false)

import utils


class CommitsQueries(utils.HttpMockTestCase):
    """Test commit querying"""
    def test_list(self):
        commits = self.client.commits.list('JNRowe/misc-overlay')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '37233b357d1a3648434ffda8f569ce96b3bcbf53')

    def test_list_with_branch(self):
        commits = self.client.commits.list('JNRowe/misc-overlay', 'gh-pages')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '482f657443df4b701137a3025ae08476cddd2b7d')

    def test_list_with_file(self):
        commits = self.client.commits.list('JNRowe/misc-overlay',
                                           file='Makefile')
        assert_equals(len(commits), 31)
        assert_equals(commits[0].id,
                '41bcd985139189763256a8c82b8f0fcbe150eb03')

    def test_list_with_branch_and_file(self):
        commits = self.client.commits.list('JNRowe/misc-overlay', 'gh-pages',
                                           'packages/dev-python.html')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '482f657443df4b701137a3025ae08476cddd2b7d')

    def test_list_repo_with_dot(self):
        """GitHub returns error listing commits in repos containing '.'

        The purpose of this test is to tell us when this issue is fixed
        upstream.
        """
        try:
            commits = self.client.commits.list('kennethreitz/osxpython.org')
        except RuntimeError:
            # The hoop jumping here is for Python 2 & 3 compatibility, it is
            # also good a sign it may be time to use 2to3 on the tests.
            e = sys.exc_info()[1]
            if """'{"error":"Not Found"}'""" not in e.args[0]:
                raise
            commits = None
        assert_false(commits,
                     "Listing commits with '.' in name is fixed upstream!")

==> github2-0.5.2.tar.gz: github2-0.5.2/tests/test_commits.py <==
import _setup

from nose.tools import assert_equals

import utils


class Commit(utils.HttpMockTestCase):
    def test_repr(self):
        commit_id = '1c83cde9b5a7c396a01af1007fb7b88765b9ae45'
        commit = self.client.commits.show('ask/python-github2', commit_id)
        assert_equals(repr(commit),
                      '<Commit: %s Added cache suppo...>' % commit_id[:8])


class CommitsQueries(utils.HttpMockTestCase):
    """Test commit querying"""
    def test_list(self):
        commits = self.client.commits.list('JNRowe/misc-overlay')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '4de0834d58b37ef3020c49df43c95649217a2def')

    def test_list_with_branch(self):
        commits = self.client.commits.list('JNRowe/misc-overlay', 'gh-pages')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '025148bdaa6fb6bdac9c3522d481fadf1c0a456f')

    def test_list_with_file(self):
        commits = self.client.commits.list('JNRowe/misc-overlay',
                                           file='Makefile')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                'fc12b924d34dc38c8ce76d27a866221faa88cb72')

    def test_list_with_branch_and_file(self):
        commits = self.client.commits.list('JNRowe/misc-overlay', 'gh-pages',
                                           'packages/dev-python.html')
        assert_equals(len(commits), 35)
        assert_equals(commits[0].id,
                '025148bdaa6fb6bdac9c3522d481fadf1c0a456f')
